# aCrypt
Ciphering made easy.

## Usage

| Usage          | Params                   | Return Value      |
| :------------- | :----------------------- | :---------------- |
| `create_key()` | `None: None`             | `int: key`        |
| `cipher()`     | `str: message, int: key` | `str: ciphered`   |
| `decipher()`   | `str: message, int: key` | `str: deciphered` |
| `a_credits()`  | `None: None`             | `None: None`      |